==> cppad_2017.00.00.4.orig.tar.gz: cppad-20170000.4/doc/_revsparsehes_xml.js <==
var list_across0 = [
'_contents_xml.htm',
'_reference.xml',
'_index.xml',
'_search_xml.htm',
'_external.xml'
];
var list_up0 = [
'cppad.xml',
'adfun.xml',
'funeval.xml',
'sparse.xml',
'revsparsehes.xml'
];
var list_down3 = [
'independent.xml',
'funconstruct.xml',
'dependent.xml',
'abort_recording.xml',
'seq_property.xml',
'funeval.xml',
'drivers.xml',
'funcheck.xml',
'optimize.xml',
'check_for_nan.xml'
];
var list_down2 = [
'forward.xml',
'reverse.xml',
'sparse.xml'
];
var list_down1 = [
'forsparsejac.xml',
'revsparsejac.xml',
'dependency.cpp.xml',
'revsparsehes.xml',
'forsparsehes.xml',
'bool_sparsity.cpp.xml'
];
var list_down0 = [
'rev_sparse_hes.cpp.xml',
'sparsity_sub.cpp.xml'
];
var list_current0 = [
'revsparsehes.xml#Syntax',
'revsparsehes.xml#Purpose',
'revsparsehes.xml#f',
'revsparsehes.xml#x',
'revsparsehes.xml#q',
'revsparsehes.xml#transpose',
'revsparsehes.xml#r',
'revsparsehes.xml#s',
'revsparsehes.xml#h',
'revsparsehes.xml#h.transpose false',
'revsparsehes.xml#h.transpose true',
'revsparsehes.xml#VectorSet',
'revsparsehes.xml#Entire Sparsity Pattern',
'revsparsehes.xml#Example'
];
function choose_across0(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_across0[index-1];
}
function choose_up0(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_up0[index-1];
}
function choose_down3(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_down3[index-1];
}
function choose_down2(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_down2[index-1];
}
function choose_down1(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_down1[index-1];
}
function choose_down0(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_down0[index-1];
}
function choose_current0(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_current0[index-1];
}

==> cppad_2018.00.00.0.orig.tar.gz: cppad-20180000.0/doc/_revsparsehes_xml.js <==
var list_across0 = [
'_contents_xml.htm',
'_reference.xml',
'_index.xml',
'_search_xml.htm',
'_external.xml'
];
var list_up0 = [
'cppad.xml',
'adfun.xml',
'sparsity_pattern.xml',
'revsparsehes.xml'
];
var list_down3 = [
'install.xml',
'introduction.xml',
'ad.xml',
'adfun.xml',
'preprocessor.xml',
'multi_thread.xml',
'utility.xml',
'ipopt_solve.xml',
'example.xml',
'speed.xml',
'appendix.xml'
];
var list_down2 = [
'record_adfun.xml',
'drivers.xml',
'forward.xml',
'reverse.xml',
'sparsity_pattern.xml',
'sparse_derivative.xml',
'optimize.xml',
'abs_normal.xml',
'funcheck.xml',
'check_for_nan.xml'
];
var list_down1 = [
'for_jac_sparsity.xml',
'forsparsejac.xml',
'rev_jac_sparsity.xml',
'revsparsejac.xml',
'rev_hes_sparsity.xml',
'revsparsehes.xml',
'for_hes_sparsity.xml',
'forsparsehes.xml',
'dependency.cpp.xml',
'rc_sparsity.cpp.xml',
'subgraph_sparsity.xml'
];
var list_down0 = [
'rev_sparse_hes.cpp.xml',
'sparsity_sub.cpp.xml'
];
var list_current0 = [
'revsparsehes.xml#Syntax',
'revsparsehes.xml#Purpose',
'revsparsehes.xml#f',
'revsparsehes.xml#x',
'revsparsehes.xml#q',
'revsparsehes.xml#transpose',
'revsparsehes.xml#r',
'revsparsehes.xml#s',
'revsparsehes.xml#h',
'revsparsehes.xml#h.transpose false',
'revsparsehes.xml#h.transpose true',
'revsparsehes.xml#VectorSet',
'revsparsehes.xml#Entire Sparsity Pattern',
'revsparsehes.xml#Example'
];
function choose_across0(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_across0[index-1];
}
function choose_up0(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_up0[index-1];
}
function choose_down3(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_down3[index-1];
}
function choose_down2(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_down2[index-1];
}
function choose_down1(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_down1[index-1];
}
function choose_down0(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_down0[index-1];
}
function choose_current0(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_current0[index-1];
}
